% --- Source file: man/samc.train.Rd ---
\name{BSR.samc}
\alias{BSR.samc}
\title{BSR.samc}
\description{Apply SAMC to estimate the posterior distribution of the model. Four output files are generated.
  The .log file contains the summary of the model posterior distribution, such as the size, the best model for
 a given size, and the probability of a variable included in a model. The .hist file contains the probability
 for each partition region estimated from the SAMC algorithm. The .out1 file contains the summary for each (biased)
 sampled model. The .out2 file contains the estimated coefficients for each model listed in the .out1 file. The .model
 file contains results for all the models that have been considered.
}
\usage{
BSR.samc(data, outdir, response.var, id.var, vars0, groups=NULL, 
           interactions=NULL, op=NULL)}

\arguments{
  \item{data}{See \code{\link{BSR}}.}
  \item{outdir}{See \code{\link{BSR}}.}
  \item{response.var}{See \code{\link{BSR}}.}
  \item{id.var}{See \code{\link{BSR}}.}
  \item{vars0}{See \code{\link{BSR}}.}
  \item{groups}{See \code{\link{BSR}}.}
  \item{interactions}{See \code{\link{BSR}}.}
  \item{op}{List of options. See \code{details} for all possible options.}
}
\value{
 A list of the output files created in \code{outdir} and if the input data frame was modified, then the modified data frame
  is also returned.
 
}
\details{
  The input \code{data} frame will use all variables in the data frame as covariates except \code{response.var} and
   \code{id.var}. All variables except for \code{id.var} must be numeric and continuous. Rows with missing values will be 
   removed from the analysis. 
  
 \bold{Options list:} \cr

 Below are the names for the options list \code{op}. All names have default values
         if they are not specified. 
  \itemize{
  \item \code{stepscale} This is the value called t_0 in equation (26) from the paper by Liang (2013). The default is 1000. 
  \item \code{total_iteration} Number of iterations. The default is 500000. 
  \item \code{warm} The number of warm-up iterations. The default is 10000. 
  \item \code{savestep} Number to output every \code{savestep} iterations. The default is 1. 
  \item \code{lowE, maxE, scale} These options are used for defining the sample space partition according to the energy
                function. The lower and upper boundaries are defined by \code{lowE} and \code{maxE}. The option
                \code{scale} is used to control the number of subregions defined as \code{(maxE-lowE)*scale}. 
                The default value of \code{scale} is 1, but \code{lowE} and \code{maxE} must be provided.
  \item \code{rho} The parameter for the SAMC algorithm. The default is 1.
  \item \code{temperature} The parameter for the MCMC move. The default is 1. 
  \item \code{maxvar}  Maximum number of variables in the regression model. The default is 20.
  \item \code{maxbeta} Maximum allowed value for abs(beta) in the regression model.
          If the model has any abs(beta) > \code{maxbeta}, then the model is rejected.  The default is 10.
  \item \code{seed} The default seed is computed from the time. 
  \item \code{gamma} The penalty parameter. The default is 0.5.
  \item \code{model_maxn} Maximum number of models to save. The default is 100000.
  \item \code{out.string} Character string to include in the output files. The default is "".
  \item \code{delete} 0 or 1 to delete the temporary files written to \code{outdir}. The default is 0.
  

  } % END: itemize

}
\seealso{\code{\link{BSR.sample.model}}, \code{\link{BSR.prediction}}, \code{\link{BSR}}}
\author{Faming Liang, William Wheeler, Kai Yu}
\examples{

  # Create data
  set.seed(123)
  n    <- 100
  m    <- 50
  y    <- rbinom(n, 1, 0.5)
  id   <- paste("sub_", 1:n, sep="")
  int  <- rep(1, n)
  z1   <- rbinom(n, 1, 0.5)
  z2   <- rbinom(n, 1, 0.5)
  z3   <- runif(n)
  z4   <- runif(n)
  data <- data.frame(y, id, int, z1, z2, z3, z4)

  outdir     <- "c:/temp/"
  vars0      <- "int"  # The intercept variable
  
  # Options for a small test run
  op <- list(lowE=0, maxE=1000, total_iteration=100, warm=10)

  # Not run
  #ret <- BSR.samc(data, outdir, "y", "id", vars0, groups=NULL,
  #       interactions=NULL,  op=op)
  
}