
#ifndef __SAMC_H__
#define __SAMC_H__

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include "./nrutil.h"


#define DEBUG 0

#define END_OF_LINE '\n'
#define CAR_RETURN '\r'
#define END_OF_STR '\0'
#define BAD_RETURN 1.0e+110
#define BUFFERSIZE 100000
#define BUFFERSIZE_INT 1000
#define MAXFILELEN 1000
#define ALMOST_ZERO 1e-10
#define NOTFOUND -9999
#define MODEL_MAXN 10000
#define MODEL_ADDN 1000
#define MINLOGARG 1e-300
#define LOGMINLOGARG -690.77552789821368151
#define MAXIT_COST 100
#define MAX_BETA 1000
#define INVERSE_FAIL -9999
#define LOGDET_FAIL -1.0e300

#define CHECK_MEM(obj) if (obj == NULL) {printf("ERROR: allocating memory \n"); exit(0);}
#define MAX( a, b ) ( ((a) > (b)) ? (a) : (b) )
#define MIN( a, b ) ( ((a) < (b)) ? (a) : (b) )
#define MYLOG(a) ( ((a) > MINLOGARG) ? log((a)) :  LOGMINLOGARG )


struct ret_cost {
  double *Yhat;
  double value;  
  double deviance;
  int dim; /* total dimension in the model */
  int num_grp; /*number of selected group */
  int converged;

  int *groups;  /* Sorted in increasing order (Original group id) */
  int *col_ids; /* To compute Yhat */
  double *beta; /* To compute Yhat */
};
typedef struct ret_cost RET_COST;

struct parms {
  int stepscale, total_iteration, warm, savestep, maxvar, response_col;
  double lowE, maxE, scale, rho, temperature;
  int check_interactions;
  int Model_maxn; /* Maximum number of Models */
  int seed;
  double gamma;
  double maxbeta; /* Maximum value of abs(beta) for convergence */

  int DataNum, DataP;
  int *bestx, sze,**modsave;
  double *refden, bestvalue, *fsave, accept_loc,total_loc;
  double **DataX, *DataY, *cor;
  int *Data0X, Data0X_n;
  int **GroupX, *GroupN, TotalNcol, Sum_GroupN;
  int **IntX, IntX_flag;
  int *IntX_N;  /* Number of variables that must be in the model, if group i is in the model */
  RET_COST **Models; /* Vector of pointers to structures that contain the model info. */
  int Model_n; /* Current number of models */
  
  int *ranks;  
  /* Vector of length DataP to give the order of each group */
  int *indx;  
  /* Vector of length DataP that gives group id for the ith ranked group */

  int newModel; /* This is set in the cost function to 1 if the model is a new model */
};
typedef struct parms PARMS;

FILE * open_file(char *, char *);
char getDelimiter(char *, long);
int getNrows(char *, long);
int getNcols(char *, char, long);

int get_option(char *, char *, char *, int);
void read_parms(PARMS *, char *);
char * next_token(char *, int, char);
int copy_token(char *, char *, char, int);
RET_COST * cost_init(int, int, int);
void cost_free(RET_COST *, int);
void cost_copy(RET_COST *, int, RET_COST *);
int getIntsFromStr(char *, int, int, int *);
void read_data(char *, char, double **, int, int, long, int);
int ** read_interactions(char *, int, int *);
int read_groups(char *, int *, int, int **);
int getHeader(char *, char, int, long);
void models_free(PARMS *);
int find_row(int *, int, int *, PARMS *);
void insert_model(int, RET_COST *, PARMS *);
void post_prob(int, double *, PARMS *);
int model_max_value(PARMS *);
void set_Models(char *, PARMS *);
void write_Models(char *, PARMS *);
void write_model(FILE *, RET_COST *, int);
double ** set_hist(char *, int *, int *, PARMS *);
void cost(int *, RET_COST *, int, PARMS *);
int Metropolis_ini(int *, double *, RET_COST *, int, PARMS *);
int metmove(int *, double *, double **, double, double *, RET_COST *, int, int, PARMS *);
void indexx(int, double *, int *);
double gammpln(double, double, int *);
double inverse_normal_cdf(double);
double inverse_normal_cdf_log(double);
void indexx_convert_integer(int, int *, int *, int *);
void indexx_convert_double(int, int *, double *, double *);
double matrix_inverse(double **, double **, int);
void matrix_free(void **, int);


void copy_ivec(int *, int *, int, int);
void copy_dvec(double *, double *, int, int);

void print_dVec(double *, int, char *);
void print_dMat(double **, int, int, int, int, char *);
void print_iMat(int **, int, int, char *);
void print_iVec(int *, int, char *);
void print_Models(int, PARMS *);
void print_cost(RET_COST *);



#endif
